==> haskell-hasql-transaction-1.0.1.1-234-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-transaction
version:              1.0.1.1
visibility:           public
id:                   hasql-transaction-1.0.1.1-G76BqD6aHhG2Tv6Ck78aUa
key:                  hasql-transaction-1.0.1.1-G76BqD6aHhG2Tv6Ck78aUa
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-transaction
synopsis:
    Composable abstraction over retryable transactions for Hasql

category:             Hasql, Database, PostgreSQL
abi:                  69490a17632afd29aa8f16e91169a663
exposed:              True
exposed-modules:      Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules:
    Hasql.Transaction.Private.Prelude Hasql.Transaction.Private.Model
    Hasql.Transaction.Private.SQL Hasql.Transaction.Private.Statements
    Hasql.Transaction.Private.Sessions
    Hasql.Transaction.Private.Transaction

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hasql-transaction-1.0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hasql-transaction-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-transaction
hs-libraries:         HShasql-transaction-1.0.1.1-G76BqD6aHhG2Tv6Ck78aUa
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    bytestring-tree-builder-0.2.7.10-2FtBM1hWPI46UmkKZENuzh
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
    contravariant-extras-0.3.5.4-8ACsSYmvVzs86FtthivCJ6
    hasql-1.5.0.4-3X2mZlxdWL044URuQ7OkF4 mtl-2.2.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock

haddock-html:         /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-transaction-1.0.1.1-247-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-transaction
version:              1.0.1.1
visibility:           public
id:                   hasql-transaction-1.0.1.1-IuxuKssFdu68lphT2xasPe
key:                  hasql-transaction-1.0.1.1-IuxuKssFdu68lphT2xasPe
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-transaction
synopsis:
    Composable abstraction over retryable transactions for Hasql

category:             Hasql, Database, PostgreSQL
abi:                  3a6fb67ac257cdba5a8bbdb7958ec4ab
exposed:              True
exposed-modules:      Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules:
    Hasql.Transaction.Private.Prelude Hasql.Transaction.Private.Model
    Hasql.Transaction.Private.SQL Hasql.Transaction.Private.Statements
    Hasql.Transaction.Private.Sessions
    Hasql.Transaction.Private.Transaction

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hasql-transaction-1.0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hasql-transaction-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-transaction
hs-libraries:         HShasql-transaction-1.0.1.1-IuxuKssFdu68lphT2xasPe
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    bytestring-tree-builder-0.2.7.10-KFckFj1AcKz3g1LUmsLz3M
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
    contravariant-extras-0.3.5.4-KQODmY3btn6QQJWMypRoY
    hasql-1.5.0.4-6GDwBu1ouGLL97aqfLNtDJ mtl-2.2.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock

haddock-html:         /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
